allowExtraKeys method
Allows the object to have extra keys beyond the defined schema.
Implementation
ObjectValidator allowExtraKeys() {
_allowExtraKeys = true;
return this;
}
Allows the object to have extra keys beyond the defined schema.
ObjectValidator allowExtraKeys() {
_allowExtraKeys = true;
return this;
}